#!/usr/bin/env python
# coding: utf-8

import matplotlib
matplotlib.use('Agg')
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from matplotlib import pyplot

from gwpy.timeseries import TimeSeries
from gwpy.segments import Segment
from gwpy.plot import Plot
from gwpy.time import tconvert
from astropy.time import Time

import pylab

matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['axes.labelsize'] = 9
matplotlib.rcParams['legend.fontsize'] = 9
matplotlib.rcParams['xtick.labelsize'] = 9
matplotlib.rcParams['ytick.labelsize'] = 9
matplotlib.rcParams['font.size'] = 9
matplotlib.rcParams['savefig.dpi'] = 300
matplotlib.rcParams['text.latex.preamble'] = [r'\usepackage{amsmath}',r'\mathchardef\mhyphen="2D']
matplotlib.rcParams['legend.fontsize'] = 9


# labels for each subplot
label = {
    'H1': r"$\mathrm{LIGO\ Hanford}$",
    'L1': r"$\mathrm{LIGO\ Livingston}$",
    'V1': r"$\mathrm{Virgo}$",
}

# location of data if not reading from local frame
source = {  # (channel, frametype)
    'H1': ('H1:DCS-CALIB_STRAIN_CLEAN_C01'),
    'L1': ('L1:DCS-CALIB_STRAIN_CLEAN_C01'),
    'V1': ('V1:Hrec_hoft_16384Hz')
}

framestore = {
    'H1':'GW200115_042309_H1_data.gwf',
    'L1':'GW200115_042309_L1_data.gwf',
    'V1':'GW200115_042309_V1_data.gwf'
}

# -- setup and data access ----------------------------------------------------

# define times
start = 1263097350
end = 1263097409
eventtime = 1263097407.7420
epoch = 1263097407


# plotting parameters
xlim = (-15, 1)
ylim = (10, 1000)
elim = (0, 10)
alim = (0, 15)
dx = 2.0  # tick-step for time axis
dxm = 0.5

# get data
ifos = ['H1', 'L1', 'V1']

output_plot = 'GW200115-spectrogram'


data = TimeSeries.DictClass()
for ifo in ifos:
    data[ifo] = TimeSeries.read(framestore[ifo],
                                channel=source[ifo],
                                start=start, end=end).astype('float64')
    print('reading from saved .gwf file for %s'%ifo)

q_trans = {}
fixed_q = None
qrange = (40,60)
for i in ifos:
    data[i].t0 -= epoch * data[ifo].t0.unit
    q_trans[i] =  data[i].q_transform(qrange=qrange,
                                 outseg=Segment(xlim[0], xlim[1]))
    if not fixed_q:
        fixed_q = q_trans[i].q
        print ('using a Q value of %.2f'%fixed_q)
        qrange = (fixed_q,fixed_q)

plot, axes = pyplot.subplots(nrows=len(data), sharex=True, figsize=(3.375,3.375*1.5))
for i, ax in zip(ifos,axes):
    pcm = ax.imshow(q_trans[i],vmin=0,vmax=15)
    ax.set_xlim(xlim[0],xlim[1])
    ax.set_ylim(ylim[0],ylim[1])
    ax.set_xlabel('')
    ax.set_yscale('log')
    ax.plot([-100], label=label[i], visible=False)
    ax.grid(alpha=0.6)
    ax.legend(loc='upper left', handlelength=0, handletextpad=0)
    k = ax.get_yticks().tolist()
    k[1]='$10$'
    k[2]='$100$'
    k[3]='$10^3$'
    ax.set_yticklabels(k)

axes[1].set_ylabel(r"$\mathrm{Frequency \ (Hz)}$")
axes[0].set_title(r"$\mathrm{GW200115}$", y=1.0)

iso = Time(epoch, format='gps', scale='utc').iso
utc = iso.rstrip('0').rstrip('.')
utc_latex = utc.replace(" ","\ ").replace(":","{:}").replace("-","\mhyphen ")
axes[-1].set_xlabel(r"$\mathrm{Time \ (seconds)}$")

plot.subplots_adjust(top=0.85)
for ext in ('pdf', 'png'):
    print('Saving %s' % ext.upper())
    pyplot.savefig('%s.%s' % (output_plot,ext),bbox_inches='tight')
